#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RecruitEnrollBaseInfo(object):

    def __init__(self):
        self._create_time = None
        self._enroll_id = None
        self._plan_id = None
        self._status = None
        self._status_description = None

    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def enroll_id(self):
        return self._enroll_id

    @enroll_id.setter
    def enroll_id(self, value):
        self._enroll_id = value
    @property
    def plan_id(self):
        return self._plan_id

    @plan_id.setter
    def plan_id(self, value):
        self._plan_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def status_description(self):
        return self._status_description

    @status_description.setter
    def status_description(self, value):
        self._status_description = value


    def to_alipay_dict(self):
        params = dict()
        if self.create_time:
            if hasattr(self.create_time, 'to_alipay_dict'):
                params['create_time'] = self.create_time.to_alipay_dict()
            else:
                params['create_time'] = self.create_time
        if self.enroll_id:
            if hasattr(self.enroll_id, 'to_alipay_dict'):
                params['enroll_id'] = self.enroll_id.to_alipay_dict()
            else:
                params['enroll_id'] = self.enroll_id
        if self.plan_id:
            if hasattr(self.plan_id, 'to_alipay_dict'):
                params['plan_id'] = self.plan_id.to_alipay_dict()
            else:
                params['plan_id'] = self.plan_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.status_description:
            if hasattr(self.status_description, 'to_alipay_dict'):
                params['status_description'] = self.status_description.to_alipay_dict()
            else:
                params['status_description'] = self.status_description
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RecruitEnrollBaseInfo()
        if 'create_time' in d:
            o.create_time = d['create_time']
        if 'enroll_id' in d:
            o.enroll_id = d['enroll_id']
        if 'plan_id' in d:
            o.plan_id = d['plan_id']
        if 'status' in d:
            o.status = d['status']
        if 'status_description' in d:
            o.status_description = d['status_description']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ItemResp(object):

    def __init__(self):
        self._category = None
        self._has_recive = None
        self._icon = None
        self._image = None
        self._item_id = None
        self._meaning = None
        self._org_price = None
        self._price = None
        self._shop_id = None
        self._summary = None
        self._tags = None
        self._tips = None
        self._title = None
        self._type = None
        self._url = None

    @property
    def category(self):
        return self._category

    @category.setter
    def category(self, value):
        self._category = value
    @property
    def has_recive(self):
        return self._has_recive

    @has_recive.setter
    def has_recive(self, value):
        self._has_recive = value
    @property
    def icon(self):
        return self._icon

    @icon.setter
    def icon(self, value):
        self._icon = value
    @property
    def image(self):
        return self._image

    @image.setter
    def image(self, value):
        self._image = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def meaning(self):
        return self._meaning

    @meaning.setter
    def meaning(self, value):
        self._meaning = value
    @property
    def org_price(self):
        return self._org_price

    @org_price.setter
    def org_price(self, value):
        self._org_price = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def summary(self):
        return self._summary

    @summary.setter
    def summary(self, value):
        self._summary = value
    @property
    def tags(self):
        return self._tags

    @tags.setter
    def tags(self, value):
        self._tags = value
    @property
    def tips(self):
        return self._tips

    @tips.setter
    def tips(self, value):
        self._tips = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value


    def to_alipay_dict(self):
        params = dict()
        if self.category:
            if hasattr(self.category, 'to_alipay_dict'):
                params['category'] = self.category.to_alipay_dict()
            else:
                params['category'] = self.category
        if self.has_recive:
            if hasattr(self.has_recive, 'to_alipay_dict'):
                params['has_recive'] = self.has_recive.to_alipay_dict()
            else:
                params['has_recive'] = self.has_recive
        if self.icon:
            if hasattr(self.icon, 'to_alipay_dict'):
                params['icon'] = self.icon.to_alipay_dict()
            else:
                params['icon'] = self.icon
        if self.image:
            if hasattr(self.image, 'to_alipay_dict'):
                params['image'] = self.image.to_alipay_dict()
            else:
                params['image'] = self.image
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.meaning:
            if hasattr(self.meaning, 'to_alipay_dict'):
                params['meaning'] = self.meaning.to_alipay_dict()
            else:
                params['meaning'] = self.meaning
        if self.org_price:
            if hasattr(self.org_price, 'to_alipay_dict'):
                params['org_price'] = self.org_price.to_alipay_dict()
            else:
                params['org_price'] = self.org_price
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.summary:
            if hasattr(self.summary, 'to_alipay_dict'):
                params['summary'] = self.summary.to_alipay_dict()
            else:
                params['summary'] = self.summary
        if self.tags:
            if hasattr(self.tags, 'to_alipay_dict'):
                params['tags'] = self.tags.to_alipay_dict()
            else:
                params['tags'] = self.tags
        if self.tips:
            if hasattr(self.tips, 'to_alipay_dict'):
                params['tips'] = self.tips.to_alipay_dict()
            else:
                params['tips'] = self.tips
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.url:
            if hasattr(self.url, 'to_alipay_dict'):
                params['url'] = self.url.to_alipay_dict()
            else:
                params['url'] = self.url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ItemResp()
        if 'category' in d:
            o.category = d['category']
        if 'has_recive' in d:
            o.has_recive = d['has_recive']
        if 'icon' in d:
            o.icon = d['icon']
        if 'image' in d:
            o.image = d['image']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'meaning' in d:
            o.meaning = d['meaning']
        if 'org_price' in d:
            o.org_price = d['org_price']
        if 'price' in d:
            o.price = d['price']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'summary' in d:
            o.summary = d['summary']
        if 'tags' in d:
            o.tags = d['tags']
        if 'tips' in d:
            o.tips = d['tips']
        if 'title' in d:
            o.title = d['title']
        if 'type' in d:
            o.type = d['type']
        if 'url' in d:
            o.url = d['url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VoucherPackageSalesLiteInfo(object):

    def __init__(self):
        self._budget = None
        self._sale_price = None

    @property
    def budget(self):
        return self._budget

    @budget.setter
    def budget(self, value):
        self._budget = value
    @property
    def sale_price(self):
        return self._sale_price

    @sale_price.setter
    def sale_price(self, value):
        self._sale_price = value


    def to_alipay_dict(self):
        params = dict()
        if self.budget:
            if hasattr(self.budget, 'to_alipay_dict'):
                params['budget'] = self.budget.to_alipay_dict()
            else:
                params['budget'] = self.budget
        if self.sale_price:
            if hasattr(self.sale_price, 'to_alipay_dict'):
                params['sale_price'] = self.sale_price.to_alipay_dict()
            else:
                params['sale_price'] = self.sale_price
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherPackageSalesLiteInfo()
        if 'budget' in d:
            o.budget = d['budget']
        if 'sale_price' in d:
            o.sale_price = d['sale_price']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ChannelItem(object):

    def __init__(self):
        self._asset_id = None
        self._asset_type = None
        self._asset_type_code = None
        self._channel_index = None
        self._inst_id = None
        self._logo = None
        self._name = None
        self._recommend_tip = None

    @property
    def asset_id(self):
        return self._asset_id

    @asset_id.setter
    def asset_id(self, value):
        self._asset_id = value
    @property
    def asset_type(self):
        return self._asset_type

    @asset_type.setter
    def asset_type(self, value):
        self._asset_type = value
    @property
    def asset_type_code(self):
        return self._asset_type_code

    @asset_type_code.setter
    def asset_type_code(self, value):
        self._asset_type_code = value
    @property
    def channel_index(self):
        return self._channel_index

    @channel_index.setter
    def channel_index(self, value):
        self._channel_index = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def logo(self):
        return self._logo

    @logo.setter
    def logo(self, value):
        self._logo = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def recommend_tip(self):
        return self._recommend_tip

    @recommend_tip.setter
    def recommend_tip(self, value):
        self._recommend_tip = value


    def to_alipay_dict(self):
        params = dict()
        if self.asset_id:
            if hasattr(self.asset_id, 'to_alipay_dict'):
                params['asset_id'] = self.asset_id.to_alipay_dict()
            else:
                params['asset_id'] = self.asset_id
        if self.asset_type:
            if hasattr(self.asset_type, 'to_alipay_dict'):
                params['asset_type'] = self.asset_type.to_alipay_dict()
            else:
                params['asset_type'] = self.asset_type
        if self.asset_type_code:
            if hasattr(self.asset_type_code, 'to_alipay_dict'):
                params['asset_type_code'] = self.asset_type_code.to_alipay_dict()
            else:
                params['asset_type_code'] = self.asset_type_code
        if self.channel_index:
            if hasattr(self.channel_index, 'to_alipay_dict'):
                params['channel_index'] = self.channel_index.to_alipay_dict()
            else:
                params['channel_index'] = self.channel_index
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.logo:
            if hasattr(self.logo, 'to_alipay_dict'):
                params['logo'] = self.logo.to_alipay_dict()
            else:
                params['logo'] = self.logo
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.recommend_tip:
            if hasattr(self.recommend_tip, 'to_alipay_dict'):
                params['recommend_tip'] = self.recommend_tip.to_alipay_dict()
            else:
                params['recommend_tip'] = self.recommend_tip
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ChannelItem()
        if 'asset_id' in d:
            o.asset_id = d['asset_id']
        if 'asset_type' in d:
            o.asset_type = d['asset_type']
        if 'asset_type_code' in d:
            o.asset_type_code = d['asset_type_code']
        if 'channel_index' in d:
            o.channel_index = d['channel_index']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'logo' in d:
            o.logo = d['logo']
        if 'name' in d:
            o.name = d['name']
        if 'recommend_tip' in d:
            o.recommend_tip = d['recommend_tip']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PetPhoto import PetPhoto


class AlipayInsScenePetprofilePlatformprofileMatchModel(object):

    def __init__(self):
        self._pet_type = None
        self._photos = None

    @property
    def pet_type(self):
        return self._pet_type

    @pet_type.setter
    def pet_type(self, value):
        self._pet_type = value
    @property
    def photos(self):
        return self._photos

    @photos.setter
    def photos(self, value):
        if isinstance(value, list):
            self._photos = list()
            for i in value:
                if isinstance(i, PetPhoto):
                    self._photos.append(i)
                else:
                    self._photos.append(PetPhoto.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.pet_type:
            if hasattr(self.pet_type, 'to_alipay_dict'):
                params['pet_type'] = self.pet_type.to_alipay_dict()
            else:
                params['pet_type'] = self.pet_type
        if self.photos:
            if isinstance(self.photos, list):
                for i in range(0, len(self.photos)):
                    element = self.photos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.photos[i] = element.to_alipay_dict()
            if hasattr(self.photos, 'to_alipay_dict'):
                params['photos'] = self.photos.to_alipay_dict()
            else:
                params['photos'] = self.photos
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsScenePetprofilePlatformprofileMatchModel()
        if 'pet_type' in d:
            o.pet_type = d['pet_type']
        if 'photos' in d:
            o.photos = d['photos']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarViolationCityPushModel(object):

    def __init__(self):
        self._city_code = None
        self._push_type = None
        self._service_status = None

    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def push_type(self):
        return self._push_type

    @push_type.setter
    def push_type(self, value):
        self._push_type = value
    @property
    def service_status(self):
        return self._service_status

    @service_status.setter
    def service_status(self, value):
        self._service_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.push_type:
            if hasattr(self.push_type, 'to_alipay_dict'):
                params['push_type'] = self.push_type.to_alipay_dict()
            else:
                params['push_type'] = self.push_type
        if self.service_status:
            if hasattr(self.service_status, 'to_alipay_dict'):
                params['service_status'] = self.service_status.to_alipay_dict()
            else:
                params['service_status'] = self.service_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarViolationCityPushModel()
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'push_type' in d:
            o.push_type = d['push_type']
        if 'service_status' in d:
            o.service_status = d['service_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AntInvoiceResult import AntInvoiceResult


class AlipayEbppInvoiceResultGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInvoiceResultGetResponse, self).__init__()
        self._invoice_result_list = None

    @property
    def invoice_result_list(self):
        return self._invoice_result_list

    @invoice_result_list.setter
    def invoice_result_list(self, value):
        if isinstance(value, list):
            self._invoice_result_list = list()
            for i in value:
                if isinstance(i, AntInvoiceResult):
                    self._invoice_result_list.append(i)
                else:
                    self._invoice_result_list.append(AntInvoiceResult.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInvoiceResultGetResponse, self).parse_response_content(response_content)
        if 'invoice_result_list' in response:
            self.invoice_result_list = response['invoice_result_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniBaseinfoNameCheckResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniBaseinfoNameCheckResponse, self).__init__()
        self._check_code = None
        self._check_memo = None

    @property
    def check_code(self):
        return self._check_code

    @check_code.setter
    def check_code(self, value):
        self._check_code = value
    @property
    def check_memo(self):
        return self._check_memo

    @check_memo.setter
    def check_memo(self, value):
        self._check_memo = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniBaseinfoNameCheckResponse, self).parse_response_content(response_content)
        if 'check_code' in response:
            self.check_code = response['check_code']
        if 'check_memo' in response:
            self.check_memo = response['check_memo']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechBlockchainFinanceTruspleAuthloginSubmitModel(object):

    def __init__(self):
        self._cert_no = None
        self._company_cert_no = None
        self._company_name = None
        self._inst_code = None
        self._login_id = None
        self._phone_no = None
        self._state = None
        self._user_name = None

    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def company_cert_no(self):
        return self._company_cert_no

    @company_cert_no.setter
    def company_cert_no(self, value):
        self._company_cert_no = value
    @property
    def company_name(self):
        return self._company_name

    @company_name.setter
    def company_name(self, value):
        self._company_name = value
    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def login_id(self):
        return self._login_id

    @login_id.setter
    def login_id(self, value):
        self._login_id = value
    @property
    def phone_no(self):
        return self._phone_no

    @phone_no.setter
    def phone_no(self, value):
        self._phone_no = value
    @property
    def state(self):
        return self._state

    @state.setter
    def state(self, value):
        self._state = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.company_cert_no:
            if hasattr(self.company_cert_no, 'to_alipay_dict'):
                params['company_cert_no'] = self.company_cert_no.to_alipay_dict()
            else:
                params['company_cert_no'] = self.company_cert_no
        if self.company_name:
            if hasattr(self.company_name, 'to_alipay_dict'):
                params['company_name'] = self.company_name.to_alipay_dict()
            else:
                params['company_name'] = self.company_name
        if self.inst_code:
            if hasattr(self.inst_code, 'to_alipay_dict'):
                params['inst_code'] = self.inst_code.to_alipay_dict()
            else:
                params['inst_code'] = self.inst_code
        if self.login_id:
            if hasattr(self.login_id, 'to_alipay_dict'):
                params['login_id'] = self.login_id.to_alipay_dict()
            else:
                params['login_id'] = self.login_id
        if self.phone_no:
            if hasattr(self.phone_no, 'to_alipay_dict'):
                params['phone_no'] = self.phone_no.to_alipay_dict()
            else:
                params['phone_no'] = self.phone_no
        if self.state:
            if hasattr(self.state, 'to_alipay_dict'):
                params['state'] = self.state.to_alipay_dict()
            else:
                params['state'] = self.state
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainFinanceTruspleAuthloginSubmitModel()
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'company_cert_no' in d:
            o.company_cert_no = d['company_cert_no']
        if 'company_name' in d:
            o.company_name = d['company_name']
        if 'inst_code' in d:
            o.inst_code = d['inst_code']
        if 'login_id' in d:
            o.login_id = d['login_id']
        if 'phone_no' in d:
            o.phone_no = d['phone_no']
        if 'state' in d:
            o.state = d['state']
        if 'user_name' in d:
            o.user_name = d['user_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAppTestGrayModifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppTestGrayModifyResponse, self).__init__()
        self._address = None
        self._zone_name = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def zone_name(self):
        return self._zone_name

    @zone_name.setter
    def zone_name(self, value):
        self._zone_name = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppTestGrayModifyResponse, self).parse_response_content(response_content)
        if 'address' in response:
            self.address = response['address']
        if 'zone_name' in response:
            self.zone_name = response['zone_name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OperationData(object):

    def __init__(self):
        self._operation_data = None
        self._operation_type = None

    @property
    def operation_data(self):
        return self._operation_data

    @operation_data.setter
    def operation_data(self, value):
        self._operation_data = value
    @property
    def operation_type(self):
        return self._operation_type

    @operation_type.setter
    def operation_type(self, value):
        self._operation_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.operation_data:
            if hasattr(self.operation_data, 'to_alipay_dict'):
                params['operation_data'] = self.operation_data.to_alipay_dict()
            else:
                params['operation_data'] = self.operation_data
        if self.operation_type:
            if hasattr(self.operation_type, 'to_alipay_dict'):
                params['operation_type'] = self.operation_type.to_alipay_dict()
            else:
                params['operation_type'] = self.operation_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OperationData()
        if 'operation_data' in d:
            o.operation_data = d['operation_data']
        if 'operation_type' in d:
            o.operation_type = d['operation_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ActivityBaseInfo import ActivityBaseInfo
from alipay.aop.api.domain.VoucherAvailableScopeInfo import VoucherAvailableScopeInfo
from alipay.aop.api.domain.VoucherSendModeInfo import VoucherSendModeInfo
from alipay.aop.api.domain.PaymentVoucherUseRuleModify import PaymentVoucherUseRuleModify
from alipay.aop.api.domain.VoucherUseRuleInfo import VoucherUseRuleInfo


class AlipayMarketingActivityVoucherModifyModel(object):

    def __init__(self):
        self._activity_base_info = None
        self._activity_id = None
        self._merchant_access_mode = None
        self._out_biz_no = None
        self._publish_end_time = None
        self._voucher_available_scope_info = None
        self._voucher_send_mode_info = None
        self._voucher_use_rule = None
        self._voucher_use_rule_info = None

    @property
    def activity_base_info(self):
        return self._activity_base_info

    @activity_base_info.setter
    def activity_base_info(self, value):
        if isinstance(value, ActivityBaseInfo):
            self._activity_base_info = value
        else:
            self._activity_base_info = ActivityBaseInfo.from_alipay_dict(value)
    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def merchant_access_mode(self):
        return self._merchant_access_mode

    @merchant_access_mode.setter
    def merchant_access_mode(self, value):
        self._merchant_access_mode = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def publish_end_time(self):
        return self._publish_end_time

    @publish_end_time.setter
    def publish_end_time(self, value):
        self._publish_end_time = value
    @property
    def voucher_available_scope_info(self):
        return self._voucher_available_scope_info

    @voucher_available_scope_info.setter
    def voucher_available_scope_info(self, value):
        if isinstance(value, VoucherAvailableScopeInfo):
            self._voucher_available_scope_info = value
        else:
            self._voucher_available_scope_info = VoucherAvailableScopeInfo.from_alipay_dict(value)
    @property
    def voucher_send_mode_info(self):
        return self._voucher_send_mode_info

    @voucher_send_mode_info.setter
    def voucher_send_mode_info(self, value):
        if isinstance(value, VoucherSendModeInfo):
            self._voucher_send_mode_info = value
        else:
            self._voucher_send_mode_info = VoucherSendModeInfo.from_alipay_dict(value)
    @property
    def voucher_use_rule(self):
        return self._voucher_use_rule

    @voucher_use_rule.setter
    def voucher_use_rule(self, value):
        if isinstance(value, PaymentVoucherUseRuleModify):
            self._voucher_use_rule = value
        else:
            self._voucher_use_rule = PaymentVoucherUseRuleModify.from_alipay_dict(value)
    @property
    def voucher_use_rule_info(self):
        return self._voucher_use_rule_info

    @voucher_use_rule_info.setter
    def voucher_use_rule_info(self, value):
        if isinstance(value, VoucherUseRuleInfo):
            self._voucher_use_rule_info = value
        else:
            self._voucher_use_rule_info = VoucherUseRuleInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.activity_base_info:
            if hasattr(self.activity_base_info, 'to_alipay_dict'):
                params['activity_base_info'] = self.activity_base_info.to_alipay_dict()
            else:
                params['activity_base_info'] = self.activity_base_info
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.merchant_access_mode:
            if hasattr(self.merchant_access_mode, 'to_alipay_dict'):
                params['merchant_access_mode'] = self.merchant_access_mode.to_alipay_dict()
            else:
                params['merchant_access_mode'] = self.merchant_access_mode
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.publish_end_time:
            if hasattr(self.publish_end_time, 'to_alipay_dict'):
                params['publish_end_time'] = self.publish_end_time.to_alipay_dict()
            else:
                params['publish_end_time'] = self.publish_end_time
        if self.voucher_available_scope_info:
            if hasattr(self.voucher_available_scope_info, 'to_alipay_dict'):
                params['voucher_available_scope_info'] = self.voucher_available_scope_info.to_alipay_dict()
            else:
                params['voucher_available_scope_info'] = self.voucher_available_scope_info
        if self.voucher_send_mode_info:
            if hasattr(self.voucher_send_mode_info, 'to_alipay_dict'):
                params['voucher_send_mode_info'] = self.voucher_send_mode_info.to_alipay_dict()
            else:
                params['voucher_send_mode_info'] = self.voucher_send_mode_info
        if self.voucher_use_rule:
            if hasattr(self.voucher_use_rule, 'to_alipay_dict'):
                params['voucher_use_rule'] = self.voucher_use_rule.to_alipay_dict()
            else:
                params['voucher_use_rule'] = self.voucher_use_rule
        if self.voucher_use_rule_info:
            if hasattr(self.voucher_use_rule_info, 'to_alipay_dict'):
                params['voucher_use_rule_info'] = self.voucher_use_rule_info.to_alipay_dict()
            else:
                params['voucher_use_rule_info'] = self.voucher_use_rule_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingActivityVoucherModifyModel()
        if 'activity_base_info' in d:
            o.activity_base_info = d['activity_base_info']
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'merchant_access_mode' in d:
            o.merchant_access_mode = d['merchant_access_mode']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'publish_end_time' in d:
            o.publish_end_time = d['publish_end_time']
        if 'voucher_available_scope_info' in d:
            o.voucher_available_scope_info = d['voucher_available_scope_info']
        if 'voucher_send_mode_info' in d:
            o.voucher_send_mode_info = d['voucher_send_mode_info']
        if 'voucher_use_rule' in d:
            o.voucher_use_rule = d['voucher_use_rule']
        if 'voucher_use_rule_info' in d:
            o.voucher_use_rule_info = d['voucher_use_rule_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EinvTrade(object):

    def __init__(self):
        self._bill_no = None
        self._bill_time = None
        self._city_name = None
        self._detail_json = None
        self._download_url = None
        self._extend_map = None
        self._merchant_name = None
        self._out_json = None
        self._payee_name = None
        self._payment_amount = None
        self._payment_time = None
        self._souce = None
        self._trade_type = None

    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def bill_time(self):
        return self._bill_time

    @bill_time.setter
    def bill_time(self, value):
        self._bill_time = value
    @property
    def city_name(self):
        return self._city_name

    @city_name.setter
    def city_name(self, value):
        self._city_name = value
    @property
    def detail_json(self):
        return self._detail_json

    @detail_json.setter
    def detail_json(self, value):
        self._detail_json = value
    @property
    def download_url(self):
        return self._download_url

    @download_url.setter
    def download_url(self, value):
        self._download_url = value
    @property
    def extend_map(self):
        return self._extend_map

    @extend_map.setter
    def extend_map(self, value):
        self._extend_map = value
    @property
    def merchant_name(self):
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, value):
        self._merchant_name = value
    @property
    def out_json(self):
        return self._out_json

    @out_json.setter
    def out_json(self, value):
        self._out_json = value
    @property
    def payee_name(self):
        return self._payee_name

    @payee_name.setter
    def payee_name(self, value):
        self._payee_name = value
    @property
    def payment_amount(self):
        return self._payment_amount

    @payment_amount.setter
    def payment_amount(self, value):
        self._payment_amount = value
    @property
    def payment_time(self):
        return self._payment_time

    @payment_time.setter
    def payment_time(self, value):
        self._payment_time = value
    @property
    def souce(self):
        return self._souce

    @souce.setter
    def souce(self, value):
        self._souce = value
    @property
    def trade_type(self):
        return self._trade_type

    @trade_type.setter
    def trade_type(self, value):
        self._trade_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.bill_time:
            if hasattr(self.bill_time, 'to_alipay_dict'):
                params['bill_time'] = self.bill_time.to_alipay_dict()
            else:
                params['bill_time'] = self.bill_time
        if self.city_name:
            if hasattr(self.city_name, 'to_alipay_dict'):
                params['city_name'] = self.city_name.to_alipay_dict()
            else:
                params['city_name'] = self.city_name
        if self.detail_json:
            if hasattr(self.detail_json, 'to_alipay_dict'):
                params['detail_json'] = self.detail_json.to_alipay_dict()
            else:
                params['detail_json'] = self.detail_json
        if self.download_url:
            if hasattr(self.download_url, 'to_alipay_dict'):
                params['download_url'] = self.download_url.to_alipay_dict()
            else:
                params['download_url'] = self.download_url
        if self.extend_map:
            if hasattr(self.extend_map, 'to_alipay_dict'):
                params['extend_map'] = self.extend_map.to_alipay_dict()
            else:
                params['extend_map'] = self.extend_map
        if self.merchant_name:
            if hasattr(self.merchant_name, 'to_alipay_dict'):
                params['merchant_name'] = self.merchant_name.to_alipay_dict()
            else:
                params['merchant_name'] = self.merchant_name
        if self.out_json:
            if hasattr(self.out_json, 'to_alipay_dict'):
                params['out_json'] = self.out_json.to_alipay_dict()
            else:
                params['out_json'] = self.out_json
        if self.payee_name:
            if hasattr(self.payee_name, 'to_alipay_dict'):
                params['payee_name'] = self.payee_name.to_alipay_dict()
            else:
                params['payee_name'] = self.payee_name
        if self.payment_amount:
            if hasattr(self.payment_amount, 'to_alipay_dict'):
                params['payment_amount'] = self.payment_amount.to_alipay_dict()
            else:
                params['payment_amount'] = self.payment_amount
        if self.payment_time:
            if hasattr(self.payment_time, 'to_alipay_dict'):
                params['payment_time'] = self.payment_time.to_alipay_dict()
            else:
                params['payment_time'] = self.payment_time
        if self.souce:
            if hasattr(self.souce, 'to_alipay_dict'):
                params['souce'] = self.souce.to_alipay_dict()
            else:
                params['souce'] = self.souce
        if self.trade_type:
            if hasattr(self.trade_type, 'to_alipay_dict'):
                params['trade_type'] = self.trade_type.to_alipay_dict()
            else:
                params['trade_type'] = self.trade_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EinvTrade()
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'bill_time' in d:
            o.bill_time = d['bill_time']
        if 'city_name' in d:
            o.city_name = d['city_name']
        if 'detail_json' in d:
            o.detail_json = d['detail_json']
        if 'download_url' in d:
            o.download_url = d['download_url']
        if 'extend_map' in d:
            o.extend_map = d['extend_map']
        if 'merchant_name' in d:
            o.merchant_name = d['merchant_name']
        if 'out_json' in d:
            o.out_json = d['out_json']
        if 'payee_name' in d:
            o.payee_name = d['payee_name']
        if 'payment_amount' in d:
            o.payment_amount = d['payment_amount']
        if 'payment_time' in d:
            o.payment_time = d['payment_time']
        if 'souce' in d:
            o.souce = d['souce']
        if 'trade_type' in d:
            o.trade_type = d['trade_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserAgreementSignConfirmResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserAgreementSignConfirmResponse, self).__init__()
        self._agreement_no = None
        self._forex_eligible = None
        self._status = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def forex_eligible(self):
        return self._forex_eligible

    @forex_eligible.setter
    def forex_eligible(self, value):
        self._forex_eligible = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserAgreementSignConfirmResponse, self).parse_response_content(response_content)
        if 'agreement_no' in response:
            self.agreement_no = response['agreement_no']
        if 'forex_eligible' in response:
            self.forex_eligible = response['forex_eligible']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DeviceRecordFile import DeviceRecordFile
from alipay.aop.api.domain.DeviceExtParams import DeviceExtParams


class DeviceRecords(object):

    def __init__(self):
        self._biz_tid = None
        self._device_grade = None
        self._device_record_files = None
        self._ext_params = None
        self._sn = None
        self._supplier_id = None

    @property
    def biz_tid(self):
        return self._biz_tid

    @biz_tid.setter
    def biz_tid(self, value):
        self._biz_tid = value
    @property
    def device_grade(self):
        return self._device_grade

    @device_grade.setter
    def device_grade(self, value):
        self._device_grade = value
    @property
    def device_record_files(self):
        return self._device_record_files

    @device_record_files.setter
    def device_record_files(self, value):
        if isinstance(value, list):
            self._device_record_files = list()
            for i in value:
                if isinstance(i, DeviceRecordFile):
                    self._device_record_files.append(i)
                else:
                    self._device_record_files.append(DeviceRecordFile.from_alipay_dict(i))
    @property
    def ext_params(self):
        return self._ext_params

    @ext_params.setter
    def ext_params(self, value):
        if isinstance(value, DeviceExtParams):
            self._ext_params = value
        else:
            self._ext_params = DeviceExtParams.from_alipay_dict(value)
    @property
    def sn(self):
        return self._sn

    @sn.setter
    def sn(self, value):
        self._sn = value
    @property
    def supplier_id(self):
        return self._supplier_id

    @supplier_id.setter
    def supplier_id(self, value):
        self._supplier_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_tid:
            if hasattr(self.biz_tid, 'to_alipay_dict'):
                params['biz_tid'] = self.biz_tid.to_alipay_dict()
            else:
                params['biz_tid'] = self.biz_tid
        if self.device_grade:
            if hasattr(self.device_grade, 'to_alipay_dict'):
                params['device_grade'] = self.device_grade.to_alipay_dict()
            else:
                params['device_grade'] = self.device_grade
        if self.device_record_files:
            if isinstance(self.device_record_files, list):
                for i in range(0, len(self.device_record_files)):
                    element = self.device_record_files[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.device_record_files[i] = element.to_alipay_dict()
            if hasattr(self.device_record_files, 'to_alipay_dict'):
                params['device_record_files'] = self.device_record_files.to_alipay_dict()
            else:
                params['device_record_files'] = self.device_record_files
        if self.ext_params:
            if hasattr(self.ext_params, 'to_alipay_dict'):
                params['ext_params'] = self.ext_params.to_alipay_dict()
            else:
                params['ext_params'] = self.ext_params
        if self.sn:
            if hasattr(self.sn, 'to_alipay_dict'):
                params['sn'] = self.sn.to_alipay_dict()
            else:
                params['sn'] = self.sn
        if self.supplier_id:
            if hasattr(self.supplier_id, 'to_alipay_dict'):
                params['supplier_id'] = self.supplier_id.to_alipay_dict()
            else:
                params['supplier_id'] = self.supplier_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeviceRecords()
        if 'biz_tid' in d:
            o.biz_tid = d['biz_tid']
        if 'device_grade' in d:
            o.device_grade = d['device_grade']
        if 'device_record_files' in d:
            o.device_record_files = d['device_record_files']
        if 'ext_params' in d:
            o.ext_params = d['ext_params']
        if 'sn' in d:
            o.sn = d['sn']
        if 'supplier_id' in d:
            o.supplier_id = d['supplier_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ExternalContact import ExternalContact


class AlipayEbppCommunityPropertyCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppCommunityPropertyCreateResponse, self).__init__()
        self._contacts = None
        self._property_short_name = None

    @property
    def contacts(self):
        return self._contacts

    @contacts.setter
    def contacts(self, value):
        if isinstance(value, ExternalContact):
            self._contacts = value
        else:
            self._contacts = ExternalContact.from_alipay_dict(value)
    @property
    def property_short_name(self):
        return self._property_short_name

    @property_short_name.setter
    def property_short_name(self, value):
        self._property_short_name = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppCommunityPropertyCreateResponse, self).parse_response_content(response_content)
        if 'contacts' in response:
            self.contacts = response['contacts']
        if 'property_short_name' in response:
            self.property_short_name = response['property_short_name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppCommonBillkeyQueryModel(object):

    def __init__(self):
        self._biz_type = None
        self._charge_inst = None
        self._sub_biz_type = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.charge_inst:
            if hasattr(self.charge_inst, 'to_alipay_dict'):
                params['charge_inst'] = self.charge_inst.to_alipay_dict()
            else:
                params['charge_inst'] = self.charge_inst
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppCommonBillkeyQueryModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'charge_inst' in d:
            o.charge_inst = d['charge_inst']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsDataDistrictQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsDataDistrictQueryResponse, self).__init__()
        self._districts = None

    @property
    def districts(self):
        return self._districts

    @districts.setter
    def districts(self, value):
        self._districts = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsDataDistrictQueryResponse, self).parse_response_content(response_content)
        if 'districts' in response:
            self.districts = response['districts']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsSceneYfxAuditApplyModel(object):

    def __init__(self):
        self._app_key = None
        self._claim_no = None
        self._operator = None
        self._policy_no = None
        self._refuse_reason = None

    @property
    def app_key(self):
        return self._app_key

    @app_key.setter
    def app_key(self, value):
        self._app_key = value
    @property
    def claim_no(self):
        return self._claim_no

    @claim_no.setter
    def claim_no(self, value):
        self._claim_no = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def policy_no(self):
        return self._policy_no

    @policy_no.setter
    def policy_no(self, value):
        self._policy_no = value
    @property
    def refuse_reason(self):
        return self._refuse_reason

    @refuse_reason.setter
    def refuse_reason(self, value):
        self._refuse_reason = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_key:
            if hasattr(self.app_key, 'to_alipay_dict'):
                params['app_key'] = self.app_key.to_alipay_dict()
            else:
                params['app_key'] = self.app_key
        if self.claim_no:
            if hasattr(self.claim_no, 'to_alipay_dict'):
                params['claim_no'] = self.claim_no.to_alipay_dict()
            else:
                params['claim_no'] = self.claim_no
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.policy_no:
            if hasattr(self.policy_no, 'to_alipay_dict'):
                params['policy_no'] = self.policy_no.to_alipay_dict()
            else:
                params['policy_no'] = self.policy_no
        if self.refuse_reason:
            if hasattr(self.refuse_reason, 'to_alipay_dict'):
                params['refuse_reason'] = self.refuse_reason.to_alipay_dict()
            else:
                params['refuse_reason'] = self.refuse_reason
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneYfxAuditApplyModel()
        if 'app_key' in d:
            o.app_key = d['app_key']
        if 'claim_no' in d:
            o.claim_no = d['claim_no']
        if 'operator' in d:
            o.operator = d['operator']
        if 'policy_no' in d:
            o.policy_no = d['policy_no']
        if 'refuse_reason' in d:
            o.refuse_reason = d['refuse_reason']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ShopCategoryInfo import ShopCategoryInfo


class ShopSummaryInfo(object):

    def __init__(self):
        self._address = None
        self._branch_shop_name = None
        self._brand_name = None
        self._business_time = None
        self._category_infos = None
        self._city_code = None
        self._city_name = None
        self._display_status = None
        self._district_code = None
        self._district_name = None
        self._landline_no = None
        self._latitude = None
        self._logo = None
        self._logo_url = None
        self._longitude = None
        self._main_image = None
        self._main_image_url = None
        self._main_shop_name = None
        self._mobile_no = None
        self._per_pay = None
        self._principal_id = None
        self._province_code = None
        self._province_name = None
        self._shop_id = None
        self._status = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def branch_shop_name(self):
        return self._branch_shop_name

    @branch_shop_name.setter
    def branch_shop_name(self, value):
        self._branch_shop_name = value
    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def business_time(self):
        return self._business_time

    @business_time.setter
    def business_time(self, value):
        self._business_time = value
    @property
    def category_infos(self):
        return self._category_infos

    @category_infos.setter
    def category_infos(self, value):
        if isinstance(value, list):
            self._category_infos = list()
            for i in value:
                if isinstance(i, ShopCategoryInfo):
                    self._category_infos.append(i)
                else:
                    self._category_infos.append(ShopCategoryInfo.from_alipay_dict(i))
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def city_name(self):
        return self._city_name

    @city_name.setter
    def city_name(self, value):
        self._city_name = value
    @property
    def display_status(self):
        return self._display_status

    @display_status.setter
    def display_status(self, value):
        self._display_status = value
    @property
    def district_code(self):
        return self._district_code

    @district_code.setter
    def district_code(self, value):
        self._district_code = value
    @property
    def district_name(self):
        return self._district_name

    @district_name.setter
    def district_name(self, value):
        self._district_name = value
    @property
    def landline_no(self):
        return self._landline_no

    @landline_no.setter
    def landline_no(self, value):
        self._landline_no = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def logo(self):
        return self._logo

    @logo.setter
    def logo(self, value):
        self._logo = value
    @property
    def logo_url(self):
        return self._logo_url

    @logo_url.setter
    def logo_url(self, value):
        self._logo_url = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def main_image(self):
        return self._main_image

    @main_image.setter
    def main_image(self, value):
        self._main_image = value
    @property
    def main_image_url(self):
        return self._main_image_url

    @main_image_url.setter
    def main_image_url(self, value):
        self._main_image_url = value
    @property
    def main_shop_name(self):
        return self._main_shop_name

    @main_shop_name.setter
    def main_shop_name(self, value):
        self._main_shop_name = value
    @property
    def mobile_no(self):
        return self._mobile_no

    @mobile_no.setter
    def mobile_no(self, value):
        self._mobile_no = value
    @property
    def per_pay(self):
        return self._per_pay

    @per_pay.setter
    def per_pay(self, value):
        self._per_pay = value
    @property
    def principal_id(self):
        return self._principal_id

    @principal_id.setter
    def principal_id(self, value):
        self._principal_id = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def province_name(self):
        return self._province_name

    @province_name.setter
    def province_name(self, value):
        self._province_name = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.branch_shop_name:
            if hasattr(self.branch_shop_name, 'to_alipay_dict'):
                params['branch_shop_name'] = self.branch_shop_name.to_alipay_dict()
            else:
                params['branch_shop_name'] = self.branch_shop_name
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.business_time:
            if hasattr(self.business_time, 'to_alipay_dict'):
                params['business_time'] = self.business_time.to_alipay_dict()
            else:
                params['business_time'] = self.business_time
        if self.category_infos:
            if isinstance(self.category_infos, list):
                for i in range(0, len(self.category_infos)):
                    element = self.category_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.category_infos[i] = element.to_alipay_dict()
            if hasattr(self.category_infos, 'to_alipay_dict'):
                params['category_infos'] = self.category_infos.to_alipay_dict()
            else:
                params['category_infos'] = self.category_infos
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.city_name:
            if hasattr(self.city_name, 'to_alipay_dict'):
                params['city_name'] = self.city_name.to_alipay_dict()
            else:
                params['city_name'] = self.city_name
        if self.display_status:
            if hasattr(self.display_status, 'to_alipay_dict'):
                params['display_status'] = self.display_status.to_alipay_dict()
            else:
                params['display_status'] = self.display_status
        if self.district_code:
            if hasattr(self.district_code, 'to_alipay_dict'):
                params['district_code'] = self.district_code.to_alipay_dict()
            else:
                params['district_code'] = self.district_code
        if self.district_name:
            if hasattr(self.district_name, 'to_alipay_dict'):
                params['district_name'] = self.district_name.to_alipay_dict()
            else:
                params['district_name'] = self.district_name
        if self.landline_no:
            if hasattr(self.landline_no, 'to_alipay_dict'):
                params['landline_no'] = self.landline_no.to_alipay_dict()
            else:
                params['landline_no'] = self.landline_no
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.logo:
            if hasattr(self.logo, 'to_alipay_dict'):
                params['logo'] = self.logo.to_alipay_dict()
            else:
                params['logo'] = self.logo
        if self.logo_url:
            if hasattr(self.logo_url, 'to_alipay_dict'):
                params['logo_url'] = self.logo_url.to_alipay_dict()
            else:
                params['logo_url'] = self.logo_url
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.main_image:
            if hasattr(self.main_image, 'to_alipay_dict'):
                params['main_image'] = self.main_image.to_alipay_dict()
            else:
                params['main_image'] = self.main_image
        if self.main_image_url:
            if hasattr(self.main_image_url, 'to_alipay_dict'):
                params['main_image_url'] = self.main_image_url.to_alipay_dict()
            else:
                params['main_image_url'] = self.main_image_url
        if self.main_shop_name:
            if hasattr(self.main_shop_name, 'to_alipay_dict'):
                params['main_shop_name'] = self.main_shop_name.to_alipay_dict()
            else:
                params['main_shop_name'] = self.main_shop_name
        if self.mobile_no:
            if hasattr(self.mobile_no, 'to_alipay_dict'):
                params['mobile_no'] = self.mobile_no.to_alipay_dict()
            else:
                params['mobile_no'] = self.mobile_no
        if self.per_pay:
            if hasattr(self.per_pay, 'to_alipay_dict'):
                params['per_pay'] = self.per_pay.to_alipay_dict()
            else:
                params['per_pay'] = self.per_pay
        if self.principal_id:
            if hasattr(self.principal_id, 'to_alipay_dict'):
                params['principal_id'] = self.principal_id.to_alipay_dict()
            else:
                params['principal_id'] = self.principal_id
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.province_name:
            if hasattr(self.province_name, 'to_alipay_dict'):
                params['province_name'] = self.province_name.to_alipay_dict()
            else:
                params['province_name'] = self.province_name
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ShopSummaryInfo()
        if 'address' in d:
            o.address = d['address']
        if 'branch_shop_name' in d:
            o.branch_shop_name = d['branch_shop_name']
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'business_time' in d:
            o.business_time = d['business_time']
        if 'category_infos' in d:
            o.category_infos = d['category_infos']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'city_name' in d:
            o.city_name = d['city_name']
        if 'display_status' in d:
            o.display_status = d['display_status']
        if 'district_code' in d:
            o.district_code = d['district_code']
        if 'district_name' in d:
            o.district_name = d['district_name']
        if 'landline_no' in d:
            o.landline_no = d['landline_no']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'logo' in d:
            o.logo = d['logo']
        if 'logo_url' in d:
            o.logo_url = d['logo_url']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'main_image' in d:
            o.main_image = d['main_image']
        if 'main_image_url' in d:
            o.main_image_url = d['main_image_url']
        if 'main_shop_name' in d:
            o.main_shop_name = d['main_shop_name']
        if 'mobile_no' in d:
            o.mobile_no = d['mobile_no']
        if 'per_pay' in d:
            o.per_pay = d['per_pay']
        if 'principal_id' in d:
            o.principal_id = d['principal_id']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'province_name' in d:
            o.province_name = d['province_name']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ConsultParticipant import ConsultParticipant
from alipay.aop.api.domain.EnterpriseInfo import EnterpriseInfo
from alipay.aop.api.domain.RiskConsultResult import RiskConsultResult


class AlipayUserFlexiblestaffingRiskconsultQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserFlexiblestaffingRiskconsultQueryResponse, self).__init__()
        self._biz_scene = None
        self._charge_type = None
        self._consult_party = None
        self._enterprise_info = None
        self._out_biz_no = None
        self._product_code = None
        self._risk_results = None
        self._suggest_risk = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def charge_type(self):
        return self._charge_type

    @charge_type.setter
    def charge_type(self, value):
        self._charge_type = value
    @property
    def consult_party(self):
        return self._consult_party

    @consult_party.setter
    def consult_party(self, value):
        if isinstance(value, ConsultParticipant):
            self._consult_party = value
        else:
            self._consult_party = ConsultParticipant.from_alipay_dict(value)
    @property
    def enterprise_info(self):
        return self._enterprise_info

    @enterprise_info.setter
    def enterprise_info(self, value):
        if isinstance(value, EnterpriseInfo):
            self._enterprise_info = value
        else:
            self._enterprise_info = EnterpriseInfo.from_alipay_dict(value)
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def risk_results(self):
        return self._risk_results

    @risk_results.setter
    def risk_results(self, value):
        if isinstance(value, list):
            self._risk_results = list()
            for i in value:
                if isinstance(i, RiskConsultResult):
                    self._risk_results.append(i)
                else:
                    self._risk_results.append(RiskConsultResult.from_alipay_dict(i))
    @property
    def suggest_risk(self):
        return self._suggest_risk

    @suggest_risk.setter
    def suggest_risk(self, value):
        self._suggest_risk = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserFlexiblestaffingRiskconsultQueryResponse, self).parse_response_content(response_content)
        if 'biz_scene' in response:
            self.biz_scene = response['biz_scene']
        if 'charge_type' in response:
            self.charge_type = response['charge_type']
        if 'consult_party' in response:
            self.consult_party = response['consult_party']
        if 'enterprise_info' in response:
            self.enterprise_info = response['enterprise_info']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'product_code' in response:
            self.product_code = response['product_code']
        if 'risk_results' in response:
            self.risk_results = response['risk_results']
        if 'suggest_risk' in response:
            self.suggest_risk = response['suggest_risk']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditHuabeiSceneprodBenefitAddModel(object):

    def __init__(self):
        self._benefit_id = None
        self._budget_amount = None
        self._out_biz_no = None
        self._partner_id = None
        self._request_from = None
        self._upper_benefit_id = None
        self._upper_seller_id = None

    @property
    def benefit_id(self):
        return self._benefit_id

    @benefit_id.setter
    def benefit_id(self, value):
        self._benefit_id = value
    @property
    def budget_amount(self):
        return self._budget_amount

    @budget_amount.setter
    def budget_amount(self, value):
        self._budget_amount = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def request_from(self):
        return self._request_from

    @request_from.setter
    def request_from(self, value):
        self._request_from = value
    @property
    def upper_benefit_id(self):
        return self._upper_benefit_id

    @upper_benefit_id.setter
    def upper_benefit_id(self, value):
        self._upper_benefit_id = value
    @property
    def upper_seller_id(self):
        return self._upper_seller_id

    @upper_seller_id.setter
    def upper_seller_id(self, value):
        self._upper_seller_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.benefit_id:
            if hasattr(self.benefit_id, 'to_alipay_dict'):
                params['benefit_id'] = self.benefit_id.to_alipay_dict()
            else:
                params['benefit_id'] = self.benefit_id
        if self.budget_amount:
            if hasattr(self.budget_amount, 'to_alipay_dict'):
                params['budget_amount'] = self.budget_amount.to_alipay_dict()
            else:
                params['budget_amount'] = self.budget_amount
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.request_from:
            if hasattr(self.request_from, 'to_alipay_dict'):
                params['request_from'] = self.request_from.to_alipay_dict()
            else:
                params['request_from'] = self.request_from
        if self.upper_benefit_id:
            if hasattr(self.upper_benefit_id, 'to_alipay_dict'):
                params['upper_benefit_id'] = self.upper_benefit_id.to_alipay_dict()
            else:
                params['upper_benefit_id'] = self.upper_benefit_id
        if self.upper_seller_id:
            if hasattr(self.upper_seller_id, 'to_alipay_dict'):
                params['upper_seller_id'] = self.upper_seller_id.to_alipay_dict()
            else:
                params['upper_seller_id'] = self.upper_seller_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiSceneprodBenefitAddModel()
        if 'benefit_id' in d:
            o.benefit_id = d['benefit_id']
        if 'budget_amount' in d:
            o.budget_amount = d['budget_amount']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'request_from' in d:
            o.request_from = d['request_from']
        if 'upper_benefit_id' in d:
            o.upper_benefit_id = d['upper_benefit_id']
        if 'upper_seller_id' in d:
            o.upper_seller_id = d['upper_seller_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundWalletCardRefundModel(object):

    def __init__(self):
        self._asset_id_lists = None
        self._biz_scene = None
        self._merchant_id = None
        self._out_biz_no = None
        self._product_code = None

    @property
    def asset_id_lists(self):
        return self._asset_id_lists

    @asset_id_lists.setter
    def asset_id_lists(self, value):
        if isinstance(value, list):
            self._asset_id_lists = list()
            for i in value:
                self._asset_id_lists.append(i)
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.asset_id_lists:
            if isinstance(self.asset_id_lists, list):
                for i in range(0, len(self.asset_id_lists)):
                    element = self.asset_id_lists[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.asset_id_lists[i] = element.to_alipay_dict()
            if hasattr(self.asset_id_lists, 'to_alipay_dict'):
                params['asset_id_lists'] = self.asset_id_lists.to_alipay_dict()
            else:
                params['asset_id_lists'] = self.asset_id_lists
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundWalletCardRefundModel()
        if 'asset_id_lists' in d:
            o.asset_id_lists = d['asset_id_lists']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.JointAccountQuotaDTO import JointAccountQuotaDTO
from alipay.aop.api.domain.MemberExtInfo import MemberExtInfo


class JointAccountMemberDTO(object):

    def __init__(self):
        self._account_quota = None
        self._member_ext_info = None
        self._name = None
        self._open_id = None
        self._status = None
        self._user_id = None

    @property
    def account_quota(self):
        return self._account_quota

    @account_quota.setter
    def account_quota(self, value):
        if isinstance(value, JointAccountQuotaDTO):
            self._account_quota = value
        else:
            self._account_quota = JointAccountQuotaDTO.from_alipay_dict(value)
    @property
    def member_ext_info(self):
        return self._member_ext_info

    @member_ext_info.setter
    def member_ext_info(self, value):
        if isinstance(value, MemberExtInfo):
            self._member_ext_info = value
        else:
            self._member_ext_info = MemberExtInfo.from_alipay_dict(value)
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_quota:
            if hasattr(self.account_quota, 'to_alipay_dict'):
                params['account_quota'] = self.account_quota.to_alipay_dict()
            else:
                params['account_quota'] = self.account_quota
        if self.member_ext_info:
            if hasattr(self.member_ext_info, 'to_alipay_dict'):
                params['member_ext_info'] = self.member_ext_info.to_alipay_dict()
            else:
                params['member_ext_info'] = self.member_ext_info
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = JointAccountMemberDTO()
        if 'account_quota' in d:
            o.account_quota = d['account_quota']
        if 'member_ext_info' in d:
            o.member_ext_info = d['member_ext_info']
        if 'name' in d:
            o.name = d['name']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'status' in d:
            o.status = d['status']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntMerchantExpandTradeorderEventSendResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandTradeorderEventSendResponse, self).__init__()
        self._logistics_status = None
        self._order_status = None

    @property
    def logistics_status(self):
        return self._logistics_status

    @logistics_status.setter
    def logistics_status(self, value):
        self._logistics_status = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandTradeorderEventSendResponse, self).parse_response_content(response_content)
        if 'logistics_status' in response:
            self.logistics_status = response['logistics_status']
        if 'order_status' in response:
            self.order_status = response['order_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceTitleDynamicGetModel(object):

    def __init__(self):
        self._bar_code = None

    @property
    def bar_code(self):
        return self._bar_code

    @bar_code.setter
    def bar_code(self, value):
        self._bar_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.bar_code:
            if hasattr(self.bar_code, 'to_alipay_dict'):
                params['bar_code'] = self.bar_code.to_alipay_dict()
            else:
                params['bar_code'] = self.bar_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceTitleDynamicGetModel()
        if 'bar_code' in d:
            o.bar_code = d['bar_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InStockStuffInfo import InStockStuffInfo


class KoubeiSalesKbassetStuffLogisticsinstockSyncModel(object):

    def __init__(self):
        self._close_date = None
        self._erp_code = None
        self._erp_order_type = None
        self._express_company_code = None
        self._express_no = None
        self._item_infos = None
        self._receipt_id = None
        self._request_id = None
        self._warehouse_code = None

    @property
    def close_date(self):
        return self._close_date

    @close_date.setter
    def close_date(self, value):
        self._close_date = value
    @property
    def erp_code(self):
        return self._erp_code

    @erp_code.setter
    def erp_code(self, value):
        self._erp_code = value
    @property
    def erp_order_type(self):
        return self._erp_order_type

    @erp_order_type.setter
    def erp_order_type(self, value):
        self._erp_order_type = value
    @property
    def express_company_code(self):
        return self._express_company_code

    @express_company_code.setter
    def express_company_code(self, value):
        self._express_company_code = value
    @property
    def express_no(self):
        return self._express_no

    @express_no.setter
    def express_no(self, value):
        self._express_no = value
    @property
    def item_infos(self):
        return self._item_infos

    @item_infos.setter
    def item_infos(self, value):
        if isinstance(value, list):
            self._item_infos = list()
            for i in value:
                if isinstance(i, InStockStuffInfo):
                    self._item_infos.append(i)
                else:
                    self._item_infos.append(InStockStuffInfo.from_alipay_dict(i))
    @property
    def receipt_id(self):
        return self._receipt_id

    @receipt_id.setter
    def receipt_id(self, value):
        self._receipt_id = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def warehouse_code(self):
        return self._warehouse_code

    @warehouse_code.setter
    def warehouse_code(self, value):
        self._warehouse_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.close_date:
            if hasattr(self.close_date, 'to_alipay_dict'):
                params['close_date'] = self.close_date.to_alipay_dict()
            else:
                params['close_date'] = self.close_date
        if self.erp_code:
            if hasattr(self.erp_code, 'to_alipay_dict'):
                params['erp_code'] = self.erp_code.to_alipay_dict()
            else:
                params['erp_code'] = self.erp_code
        if self.erp_order_type:
            if hasattr(self.erp_order_type, 'to_alipay_dict'):
                params['erp_order_type'] = self.erp_order_type.to_alipay_dict()
            else:
                params['erp_order_type'] = self.erp_order_type
        if self.express_company_code:
            if hasattr(self.express_company_code, 'to_alipay_dict'):
                params['express_company_code'] = self.express_company_code.to_alipay_dict()
            else:
                params['express_company_code'] = self.express_company_code
        if self.express_no:
            if hasattr(self.express_no, 'to_alipay_dict'):
                params['express_no'] = self.express_no.to_alipay_dict()
            else:
                params['express_no'] = self.express_no
        if self.item_infos:
            if isinstance(self.item_infos, list):
                for i in range(0, len(self.item_infos)):
                    element = self.item_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_infos[i] = element.to_alipay_dict()
            if hasattr(self.item_infos, 'to_alipay_dict'):
                params['item_infos'] = self.item_infos.to_alipay_dict()
            else:
                params['item_infos'] = self.item_infos
        if self.receipt_id:
            if hasattr(self.receipt_id, 'to_alipay_dict'):
                params['receipt_id'] = self.receipt_id.to_alipay_dict()
            else:
                params['receipt_id'] = self.receipt_id
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.warehouse_code:
            if hasattr(self.warehouse_code, 'to_alipay_dict'):
                params['warehouse_code'] = self.warehouse_code.to_alipay_dict()
            else:
                params['warehouse_code'] = self.warehouse_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiSalesKbassetStuffLogisticsinstockSyncModel()
        if 'close_date' in d:
            o.close_date = d['close_date']
        if 'erp_code' in d:
            o.erp_code = d['erp_code']
        if 'erp_order_type' in d:
            o.erp_order_type = d['erp_order_type']
        if 'express_company_code' in d:
            o.express_company_code = d['express_company_code']
        if 'express_no' in d:
            o.express_no = d['express_no']
        if 'item_infos' in d:
            o.item_infos = d['item_infos']
        if 'receipt_id' in d:
            o.receipt_id = d['receipt_id']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'warehouse_code' in d:
            o.warehouse_code = d['warehouse_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarCarmodelQueryModel(object):

    def __init__(self):
        self._model_id = None

    @property
    def model_id(self):
        return self._model_id

    @model_id.setter
    def model_id(self, value):
        self._model_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.model_id:
            if hasattr(self.model_id, 'to_alipay_dict'):
                params['model_id'] = self.model_id.to_alipay_dict()
            else:
                params['model_id'] = self.model_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarCarmodelQueryModel()
        if 'model_id' in d:
            o.model_id = d['model_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ApUserMailInfoOpenApiResponse(object):

    def __init__(self):
        self._address = None
        self._city = None
        self._country = None
        self._county_district = None
        self._detail_address = None
        self._gmt_create = None
        self._gmt_modified = None
        self._id = None
        self._name = None
        self._pid = None
        self._province = None
        self._street = None
        self._telephone = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def country(self):
        return self._country

    @country.setter
    def country(self, value):
        self._country = value
    @property
    def county_district(self):
        return self._county_district

    @county_district.setter
    def county_district(self, value):
        self._county_district = value
    @property
    def detail_address(self):
        return self._detail_address

    @detail_address.setter
    def detail_address(self, value):
        self._detail_address = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def province(self):
        return self._province

    @province.setter
    def province(self, value):
        self._province = value
    @property
    def street(self):
        return self._street

    @street.setter
    def street(self, value):
        self._street = value
    @property
    def telephone(self):
        return self._telephone

    @telephone.setter
    def telephone(self, value):
        self._telephone = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.country:
            if hasattr(self.country, 'to_alipay_dict'):
                params['country'] = self.country.to_alipay_dict()
            else:
                params['country'] = self.country
        if self.county_district:
            if hasattr(self.county_district, 'to_alipay_dict'):
                params['county_district'] = self.county_district.to_alipay_dict()
            else:
                params['county_district'] = self.county_district
        if self.detail_address:
            if hasattr(self.detail_address, 'to_alipay_dict'):
                params['detail_address'] = self.detail_address.to_alipay_dict()
            else:
                params['detail_address'] = self.detail_address
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.province:
            if hasattr(self.province, 'to_alipay_dict'):
                params['province'] = self.province.to_alipay_dict()
            else:
                params['province'] = self.province
        if self.street:
            if hasattr(self.street, 'to_alipay_dict'):
                params['street'] = self.street.to_alipay_dict()
            else:
                params['street'] = self.street
        if self.telephone:
            if hasattr(self.telephone, 'to_alipay_dict'):
                params['telephone'] = self.telephone.to_alipay_dict()
            else:
                params['telephone'] = self.telephone
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ApUserMailInfoOpenApiResponse()
        if 'address' in d:
            o.address = d['address']
        if 'city' in d:
            o.city = d['city']
        if 'country' in d:
            o.country = d['country']
        if 'county_district' in d:
            o.county_district = d['county_district']
        if 'detail_address' in d:
            o.detail_address = d['detail_address']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'id' in d:
            o.id = d['id']
        if 'name' in d:
            o.name = d['name']
        if 'pid' in d:
            o.pid = d['pid']
        if 'province' in d:
            o.province = d['province']
        if 'street' in d:
            o.street = d['street']
        if 'telephone' in d:
            o.telephone = d['telephone']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditLoanapplyBkamcAntauthsignConsultResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditLoanapplyBkamcAntauthsignConsultResponse, self).__init__()
        self._authed = None

    @property
    def authed(self):
        return self._authed

    @authed.setter
    def authed(self, value):
        self._authed = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditLoanapplyBkamcAntauthsignConsultResponse, self).parse_response_content(response_content)
        if 'authed' in response:
            self.authed = response['authed']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CommerceAppUploadRequestContent(object):

    def __init__(self):
        self._activity_id = None
        self._body = None
        self._query = None
        self._tenant_app_id = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def body(self):
        return self._body

    @body.setter
    def body(self, value):
        self._body = value
    @property
    def query(self):
        return self._query

    @query.setter
    def query(self, value):
        self._query = value
    @property
    def tenant_app_id(self):
        return self._tenant_app_id

    @tenant_app_id.setter
    def tenant_app_id(self, value):
        self._tenant_app_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.body:
            if hasattr(self.body, 'to_alipay_dict'):
                params['body'] = self.body.to_alipay_dict()
            else:
                params['body'] = self.body
        if self.query:
            if hasattr(self.query, 'to_alipay_dict'):
                params['query'] = self.query.to_alipay_dict()
            else:
                params['query'] = self.query
        if self.tenant_app_id:
            if hasattr(self.tenant_app_id, 'to_alipay_dict'):
                params['tenant_app_id'] = self.tenant_app_id.to_alipay_dict()
            else:
                params['tenant_app_id'] = self.tenant_app_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CommerceAppUploadRequestContent()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'body' in d:
            o.body = d['body']
        if 'query' in d:
            o.query = d['query']
        if 'tenant_app_id' in d:
            o.tenant_app_id = d['tenant_app_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AgmComponentInstanceDTO(object):

    def __init__(self):
        self._id = None
        self._name = None
        self._template_code = None
        self._value = None

    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def template_code(self):
        return self._template_code

    @template_code.setter
    def template_code(self, value):
        self._template_code = value
    @property
    def value(self):
        return self._value

    @value.setter
    def value(self, value):
        self._value = value


    def to_alipay_dict(self):
        params = dict()
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.template_code:
            if hasattr(self.template_code, 'to_alipay_dict'):
                params['template_code'] = self.template_code.to_alipay_dict()
            else:
                params['template_code'] = self.template_code
        if self.value:
            if hasattr(self.value, 'to_alipay_dict'):
                params['value'] = self.value.to_alipay_dict()
            else:
                params['value'] = self.value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AgmComponentInstanceDTO()
        if 'id' in d:
            o.id = d['id']
        if 'name' in d:
            o.name = d['name']
        if 'template_code' in d:
            o.template_code = d['template_code']
        if 'value' in d:
            o.value = d['value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportTaxiOrderinfoSyncModel(object):

    def __init__(self):
        self._channel_type = None
        self._dispatcher_amount = None
        self._order_id = None
        self._request_time = None
        self._status = None
        self._sys_driver_id = None

    @property
    def channel_type(self):
        return self._channel_type

    @channel_type.setter
    def channel_type(self, value):
        self._channel_type = value
    @property
    def dispatcher_amount(self):
        return self._dispatcher_amount

    @dispatcher_amount.setter
    def dispatcher_amount(self, value):
        self._dispatcher_amount = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def request_time(self):
        return self._request_time

    @request_time.setter
    def request_time(self, value):
        self._request_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def sys_driver_id(self):
        return self._sys_driver_id

    @sys_driver_id.setter
    def sys_driver_id(self, value):
        self._sys_driver_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel_type:
            if hasattr(self.channel_type, 'to_alipay_dict'):
                params['channel_type'] = self.channel_type.to_alipay_dict()
            else:
                params['channel_type'] = self.channel_type
        if self.dispatcher_amount:
            if hasattr(self.dispatcher_amount, 'to_alipay_dict'):
                params['dispatcher_amount'] = self.dispatcher_amount.to_alipay_dict()
            else:
                params['dispatcher_amount'] = self.dispatcher_amount
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.request_time:
            if hasattr(self.request_time, 'to_alipay_dict'):
                params['request_time'] = self.request_time.to_alipay_dict()
            else:
                params['request_time'] = self.request_time
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.sys_driver_id:
            if hasattr(self.sys_driver_id, 'to_alipay_dict'):
                params['sys_driver_id'] = self.sys_driver_id.to_alipay_dict()
            else:
                params['sys_driver_id'] = self.sys_driver_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportTaxiOrderinfoSyncModel()
        if 'channel_type' in d:
            o.channel_type = d['channel_type']
        if 'dispatcher_amount' in d:
            o.dispatcher_amount = d['dispatcher_amount']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'request_time' in d:
            o.request_time = d['request_time']
        if 'status' in d:
            o.status = d['status']
        if 'sys_driver_id' in d:
            o.sys_driver_id = d['sys_driver_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoCityserviceIndustryEnergyCheckModel(object):

    def __init__(self):
        self._app_code = None
        self._scene = None
        self._user_id = None
        self._user_open_id = None

    @property
    def app_code(self):
        return self._app_code

    @app_code.setter
    def app_code(self, value):
        self._app_code = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_open_id(self):
        return self._user_open_id

    @user_open_id.setter
    def user_open_id(self, value):
        self._user_open_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_code:
            if hasattr(self.app_code, 'to_alipay_dict'):
                params['app_code'] = self.app_code.to_alipay_dict()
            else:
                params['app_code'] = self.app_code
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.user_open_id:
            if hasattr(self.user_open_id, 'to_alipay_dict'):
                params['user_open_id'] = self.user_open_id.to_alipay_dict()
            else:
                params['user_open_id'] = self.user_open_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoCityserviceIndustryEnergyCheckModel()
        if 'app_code' in d:
            o.app_code = d['app_code']
        if 'scene' in d:
            o.scene = d['scene']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'user_open_id' in d:
            o.user_open_id = d['user_open_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayTradeBuyerCreditQueryModel(object):

    def __init__(self):
        self._buyer_credit_source = None
        self._buyer_user_id = None
        self._credit_scene = None
        self._merchant_credit_source = None
        self._merchant_user_id = None

    @property
    def buyer_credit_source(self):
        return self._buyer_credit_source

    @buyer_credit_source.setter
    def buyer_credit_source(self, value):
        self._buyer_credit_source = value
    @property
    def buyer_user_id(self):
        return self._buyer_user_id

    @buyer_user_id.setter
    def buyer_user_id(self, value):
        self._buyer_user_id = value
    @property
    def credit_scene(self):
        return self._credit_scene

    @credit_scene.setter
    def credit_scene(self, value):
        self._credit_scene = value
    @property
    def merchant_credit_source(self):
        return self._merchant_credit_source

    @merchant_credit_source.setter
    def merchant_credit_source(self, value):
        self._merchant_credit_source = value
    @property
    def merchant_user_id(self):
        return self._merchant_user_id

    @merchant_user_id.setter
    def merchant_user_id(self, value):
        self._merchant_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.buyer_credit_source:
            if hasattr(self.buyer_credit_source, 'to_alipay_dict'):
                params['buyer_credit_source'] = self.buyer_credit_source.to_alipay_dict()
            else:
                params['buyer_credit_source'] = self.buyer_credit_source
        if self.buyer_user_id:
            if hasattr(self.buyer_user_id, 'to_alipay_dict'):
                params['buyer_user_id'] = self.buyer_user_id.to_alipay_dict()
            else:
                params['buyer_user_id'] = self.buyer_user_id
        if self.credit_scene:
            if hasattr(self.credit_scene, 'to_alipay_dict'):
                params['credit_scene'] = self.credit_scene.to_alipay_dict()
            else:
                params['credit_scene'] = self.credit_scene
        if self.merchant_credit_source:
            if hasattr(self.merchant_credit_source, 'to_alipay_dict'):
                params['merchant_credit_source'] = self.merchant_credit_source.to_alipay_dict()
            else:
                params['merchant_credit_source'] = self.merchant_credit_source
        if self.merchant_user_id:
            if hasattr(self.merchant_user_id, 'to_alipay_dict'):
                params['merchant_user_id'] = self.merchant_user_id.to_alipay_dict()
            else:
                params['merchant_user_id'] = self.merchant_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeBuyerCreditQueryModel()
        if 'buyer_credit_source' in d:
            o.buyer_credit_source = d['buyer_credit_source']
        if 'buyer_user_id' in d:
            o.buyer_user_id = d['buyer_user_id']
        if 'credit_scene' in d:
            o.credit_scene = d['credit_scene']
        if 'merchant_credit_source' in d:
            o.merchant_credit_source = d['merchant_credit_source']
        if 'merchant_user_id' in d:
            o.merchant_user_id = d['merchant_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ManjiangTesttttttt import ManjiangTesttttttt


class AlipayCommerceAcommunicationSsmmmmmCaptureModel(object):

    def __init__(self):
        self._activity_id = None
        self._s = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def s(self):
        return self._s

    @s.setter
    def s(self, value):
        if isinstance(value, ManjiangTesttttttt):
            self._s = value
        else:
            self._s = ManjiangTesttttttt.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.s:
            if hasattr(self.s, 'to_alipay_dict'):
                params['s'] = self.s.to_alipay_dict()
            else:
                params['s'] = self.s
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceAcommunicationSsmmmmmCaptureModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 's' in d:
            o.s = d['s']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class NotifyFieldExt(object):

    def __init__(self):
        self._accessable = None
        self._desc = None
        self._field = None
        self._name = None

    @property
    def accessable(self):
        return self._accessable

    @accessable.setter
    def accessable(self, value):
        self._accessable = value
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def field(self):
        return self._field

    @field.setter
    def field(self, value):
        self._field = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.accessable:
            if hasattr(self.accessable, 'to_alipay_dict'):
                params['accessable'] = self.accessable.to_alipay_dict()
            else:
                params['accessable'] = self.accessable
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.field:
            if hasattr(self.field, 'to_alipay_dict'):
                params['field'] = self.field.to_alipay_dict()
            else:
                params['field'] = self.field
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = NotifyFieldExt()
        if 'accessable' in d:
            o.accessable = d['accessable']
        if 'desc' in d:
            o.desc = d['desc']
        if 'field' in d:
            o.field = d['field']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class UserBusiness(object):

    def __init__(self):
        self._access_level = None
        self._business_desc = None
        self._business_id = None
        self._business_name = None
        self._business_remark = None
        self._business_status = None
        self._owner = None
        self._user_status = None

    @property
    def access_level(self):
        return self._access_level

    @access_level.setter
    def access_level(self, value):
        self._access_level = value
    @property
    def business_desc(self):
        return self._business_desc

    @business_desc.setter
    def business_desc(self, value):
        self._business_desc = value
    @property
    def business_id(self):
        return self._business_id

    @business_id.setter
    def business_id(self, value):
        self._business_id = value
    @property
    def business_name(self):
        return self._business_name

    @business_name.setter
    def business_name(self, value):
        self._business_name = value
    @property
    def business_remark(self):
        return self._business_remark

    @business_remark.setter
    def business_remark(self, value):
        self._business_remark = value
    @property
    def business_status(self):
        return self._business_status

    @business_status.setter
    def business_status(self, value):
        self._business_status = value
    @property
    def owner(self):
        return self._owner

    @owner.setter
    def owner(self, value):
        self._owner = value
    @property
    def user_status(self):
        return self._user_status

    @user_status.setter
    def user_status(self, value):
        self._user_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.access_level:
            if hasattr(self.access_level, 'to_alipay_dict'):
                params['access_level'] = self.access_level.to_alipay_dict()
            else:
                params['access_level'] = self.access_level
        if self.business_desc:
            if hasattr(self.business_desc, 'to_alipay_dict'):
                params['business_desc'] = self.business_desc.to_alipay_dict()
            else:
                params['business_desc'] = self.business_desc
        if self.business_id:
            if hasattr(self.business_id, 'to_alipay_dict'):
                params['business_id'] = self.business_id.to_alipay_dict()
            else:
                params['business_id'] = self.business_id
        if self.business_name:
            if hasattr(self.business_name, 'to_alipay_dict'):
                params['business_name'] = self.business_name.to_alipay_dict()
            else:
                params['business_name'] = self.business_name
        if self.business_remark:
            if hasattr(self.business_remark, 'to_alipay_dict'):
                params['business_remark'] = self.business_remark.to_alipay_dict()
            else:
                params['business_remark'] = self.business_remark
        if self.business_status:
            if hasattr(self.business_status, 'to_alipay_dict'):
                params['business_status'] = self.business_status.to_alipay_dict()
            else:
                params['business_status'] = self.business_status
        if self.owner:
            if hasattr(self.owner, 'to_alipay_dict'):
                params['owner'] = self.owner.to_alipay_dict()
            else:
                params['owner'] = self.owner
        if self.user_status:
            if hasattr(self.user_status, 'to_alipay_dict'):
                params['user_status'] = self.user_status.to_alipay_dict()
            else:
                params['user_status'] = self.user_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UserBusiness()
        if 'access_level' in d:
            o.access_level = d['access_level']
        if 'business_desc' in d:
            o.business_desc = d['business_desc']
        if 'business_id' in d:
            o.business_id = d['business_id']
        if 'business_name' in d:
            o.business_name = d['business_name']
        if 'business_remark' in d:
            o.business_remark = d['business_remark']
        if 'business_status' in d:
            o.business_status = d['business_status']
        if 'owner' in d:
            o.owner = d['owner']
        if 'user_status' in d:
            o.user_status = d['user_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PaymentApplyQueryOrder(object):

    def __init__(self):
        self._apply_relative_id_list = None
        self._arrangement_no = None
        self._bill_no = None
        self._inv_accept_status = None
        self._invoice_id = None
        self._ip_role_id = None
        self._settle_status_list = None
        self._type = None

    @property
    def apply_relative_id_list(self):
        return self._apply_relative_id_list

    @apply_relative_id_list.setter
    def apply_relative_id_list(self, value):
        if isinstance(value, list):
            self._apply_relative_id_list = list()
            for i in value:
                self._apply_relative_id_list.append(i)
    @property
    def arrangement_no(self):
        return self._arrangement_no

    @arrangement_no.setter
    def arrangement_no(self, value):
        self._arrangement_no = value
    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def inv_accept_status(self):
        return self._inv_accept_status

    @inv_accept_status.setter
    def inv_accept_status(self, value):
        self._inv_accept_status = value
    @property
    def invoice_id(self):
        return self._invoice_id

    @invoice_id.setter
    def invoice_id(self, value):
        self._invoice_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def settle_status_list(self):
        return self._settle_status_list

    @settle_status_list.setter
    def settle_status_list(self, value):
        if isinstance(value, list):
            self._settle_status_list = list()
            for i in value:
                self._settle_status_list.append(i)
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_relative_id_list:
            if isinstance(self.apply_relative_id_list, list):
                for i in range(0, len(self.apply_relative_id_list)):
                    element = self.apply_relative_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.apply_relative_id_list[i] = element.to_alipay_dict()
            if hasattr(self.apply_relative_id_list, 'to_alipay_dict'):
                params['apply_relative_id_list'] = self.apply_relative_id_list.to_alipay_dict()
            else:
                params['apply_relative_id_list'] = self.apply_relative_id_list
        if self.arrangement_no:
            if hasattr(self.arrangement_no, 'to_alipay_dict'):
                params['arrangement_no'] = self.arrangement_no.to_alipay_dict()
            else:
                params['arrangement_no'] = self.arrangement_no
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.inv_accept_status:
            if hasattr(self.inv_accept_status, 'to_alipay_dict'):
                params['inv_accept_status'] = self.inv_accept_status.to_alipay_dict()
            else:
                params['inv_accept_status'] = self.inv_accept_status
        if self.invoice_id:
            if hasattr(self.invoice_id, 'to_alipay_dict'):
                params['invoice_id'] = self.invoice_id.to_alipay_dict()
            else:
                params['invoice_id'] = self.invoice_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.settle_status_list:
            if isinstance(self.settle_status_list, list):
                for i in range(0, len(self.settle_status_list)):
                    element = self.settle_status_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.settle_status_list[i] = element.to_alipay_dict()
            if hasattr(self.settle_status_list, 'to_alipay_dict'):
                params['settle_status_list'] = self.settle_status_list.to_alipay_dict()
            else:
                params['settle_status_list'] = self.settle_status_list
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaymentApplyQueryOrder()
        if 'apply_relative_id_list' in d:
            o.apply_relative_id_list = d['apply_relative_id_list']
        if 'arrangement_no' in d:
            o.arrangement_no = d['arrangement_no']
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'inv_accept_status' in d:
            o.inv_accept_status = d['inv_accept_status']
        if 'invoice_id' in d:
            o.invoice_id = d['invoice_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'settle_status_list' in d:
            o.settle_status_list = d['settle_status_list']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppIndustryNucleicremindSubscribeModifyModel(object):

    def __init__(self):
        self._city_code = None
        self._open_id = None
        self._reminder_hour_list = None
        self._status = None
        self._user_id = None

    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def reminder_hour_list(self):
        return self._reminder_hour_list

    @reminder_hour_list.setter
    def reminder_hour_list(self, value):
        if isinstance(value, list):
            self._reminder_hour_list = list()
            for i in value:
                self._reminder_hour_list.append(i)
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.reminder_hour_list:
            if isinstance(self.reminder_hour_list, list):
                for i in range(0, len(self.reminder_hour_list)):
                    element = self.reminder_hour_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.reminder_hour_list[i] = element.to_alipay_dict()
            if hasattr(self.reminder_hour_list, 'to_alipay_dict'):
                params['reminder_hour_list'] = self.reminder_hour_list.to_alipay_dict()
            else:
                params['reminder_hour_list'] = self.reminder_hour_list
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppIndustryNucleicremindSubscribeModifyModel()
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'reminder_hour_list' in d:
            o.reminder_hour_list = d['reminder_hour_list']
        if 'status' in d:
            o.status = d['status']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceZhimaPreorderCreateModel(object):

    def __init__(self):
        self._alipay_store_id = None
        self._alipay_user_id = None
        self._biz_time = None
        self._isv_pid = None
        self._open_id = None
        self._openapi_app_id = None
        self._out_biz_no = None
        self._start_time = None
        self._store_id = None
        self._template_id = None
        self._template_type = None
        self._timeout_express = None

    @property
    def alipay_store_id(self):
        return self._alipay_store_id

    @alipay_store_id.setter
    def alipay_store_id(self, value):
        self._alipay_store_id = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def biz_time(self):
        return self._biz_time

    @biz_time.setter
    def biz_time(self, value):
        self._biz_time = value
    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def openapi_app_id(self):
        return self._openapi_app_id

    @openapi_app_id.setter
    def openapi_app_id(self, value):
        self._openapi_app_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def template_type(self):
        return self._template_type

    @template_type.setter
    def template_type(self, value):
        self._template_type = value
    @property
    def timeout_express(self):
        return self._timeout_express

    @timeout_express.setter
    def timeout_express(self, value):
        self._timeout_express = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_store_id:
            if hasattr(self.alipay_store_id, 'to_alipay_dict'):
                params['alipay_store_id'] = self.alipay_store_id.to_alipay_dict()
            else:
                params['alipay_store_id'] = self.alipay_store_id
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.biz_time:
            if hasattr(self.biz_time, 'to_alipay_dict'):
                params['biz_time'] = self.biz_time.to_alipay_dict()
            else:
                params['biz_time'] = self.biz_time
        if self.isv_pid:
            if hasattr(self.isv_pid, 'to_alipay_dict'):
                params['isv_pid'] = self.isv_pid.to_alipay_dict()
            else:
                params['isv_pid'] = self.isv_pid
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.openapi_app_id:
            if hasattr(self.openapi_app_id, 'to_alipay_dict'):
                params['openapi_app_id'] = self.openapi_app_id.to_alipay_dict()
            else:
                params['openapi_app_id'] = self.openapi_app_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.template_type:
            if hasattr(self.template_type, 'to_alipay_dict'):
                params['template_type'] = self.template_type.to_alipay_dict()
            else:
                params['template_type'] = self.template_type
        if self.timeout_express:
            if hasattr(self.timeout_express, 'to_alipay_dict'):
                params['timeout_express'] = self.timeout_express.to_alipay_dict()
            else:
                params['timeout_express'] = self.timeout_express
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceZhimaPreorderCreateModel()
        if 'alipay_store_id' in d:
            o.alipay_store_id = d['alipay_store_id']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'biz_time' in d:
            o.biz_time = d['biz_time']
        if 'isv_pid' in d:
            o.isv_pid = d['isv_pid']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'openapi_app_id' in d:
            o.openapi_app_id = d['openapi_app_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'store_id' in d:
            o.store_id = d['store_id']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'template_type' in d:
            o.template_type = d['template_type']
        if 'timeout_express' in d:
            o.timeout_express = d['timeout_express']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateSceneConfigCreateModel(object):

    def __init__(self):
        self._business_scene = None
        self._pid = None
        self._school_id = None
        self._school_std_code = None
        self._sign_app_id = None

    @property
    def business_scene(self):
        return self._business_scene

    @business_scene.setter
    def business_scene(self, value):
        self._business_scene = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def school_id(self):
        return self._school_id

    @school_id.setter
    def school_id(self, value):
        self._school_id = value
    @property
    def school_std_code(self):
        return self._school_std_code

    @school_std_code.setter
    def school_std_code(self, value):
        self._school_std_code = value
    @property
    def sign_app_id(self):
        return self._sign_app_id

    @sign_app_id.setter
    def sign_app_id(self, value):
        self._sign_app_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_scene:
            if hasattr(self.business_scene, 'to_alipay_dict'):
                params['business_scene'] = self.business_scene.to_alipay_dict()
            else:
                params['business_scene'] = self.business_scene
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.school_id:
            if hasattr(self.school_id, 'to_alipay_dict'):
                params['school_id'] = self.school_id.to_alipay_dict()
            else:
                params['school_id'] = self.school_id
        if self.school_std_code:
            if hasattr(self.school_std_code, 'to_alipay_dict'):
                params['school_std_code'] = self.school_std_code.to_alipay_dict()
            else:
                params['school_std_code'] = self.school_std_code
        if self.sign_app_id:
            if hasattr(self.sign_app_id, 'to_alipay_dict'):
                params['sign_app_id'] = self.sign_app_id.to_alipay_dict()
            else:
                params['sign_app_id'] = self.sign_app_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateSceneConfigCreateModel()
        if 'business_scene' in d:
            o.business_scene = d['business_scene']
        if 'pid' in d:
            o.pid = d['pid']
        if 'school_id' in d:
            o.school_id = d['school_id']
        if 'school_std_code' in d:
            o.school_std_code = d['school_std_code']
        if 'sign_app_id' in d:
            o.sign_app_id = d['sign_app_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MedicalPaymentQueryResponse import MedicalPaymentQueryResponse


class AlipayCommerceMedicalPaymentQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceMedicalPaymentQueryResponse, self).__init__()
        self._error_message = None
        self._result_code = None
        self._result_data = None

    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_data(self):
        return self._result_data

    @result_data.setter
    def result_data(self, value):
        if isinstance(value, MedicalPaymentQueryResponse):
            self._result_data = value
        else:
            self._result_data = MedicalPaymentQueryResponse.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceMedicalPaymentQueryResponse, self).parse_response_content(response_content)
        if 'error_message' in response:
            self.error_message = response['error_message']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_data' in response:
            self.result_data = response['result_data']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayIserviceCognitiveClassificationFeedbackSyncResponse(AlipayResponse):

    def __init__(self):
        super(AlipayIserviceCognitiveClassificationFeedbackSyncResponse, self).__init__()
        self._err_code = None
        self._err_msg = None
        self._success = None
        self._trace_id = None

    @property
    def err_code(self):
        return self._err_code

    @err_code.setter
    def err_code(self, value):
        self._err_code = value
    @property
    def err_msg(self):
        return self._err_msg

    @err_msg.setter
    def err_msg(self, value):
        self._err_msg = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayIserviceCognitiveClassificationFeedbackSyncResponse, self).parse_response_content(response_content)
        if 'err_code' in response:
            self.err_code = response['err_code']
        if 'err_msg' in response:
            self.err_msg = response['err_msg']
        if 'success' in response:
            self.success = response['success']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniIsvFastregisterQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniIsvFastregisterQueryResponse, self).__init__()
        self._app_name = None
        self._isv_app_id = None
        self._mini_app_id = None
        self._order_no = None
        self._out_order_no = None
        self._status = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def isv_app_id(self):
        return self._isv_app_id

    @isv_app_id.setter
    def isv_app_id(self, value):
        self._isv_app_id = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniIsvFastregisterQueryResponse, self).parse_response_content(response_content)
        if 'app_name' in response:
            self.app_name = response['app_name']
        if 'isv_app_id' in response:
            self.isv_app_id = response['isv_app_id']
        if 'mini_app_id' in response:
            self.mini_app_id = response['mini_app_id']
        if 'order_no' in response:
            self.order_no = response['order_no']
        if 'out_order_no' in response:
            self.out_order_no = response['out_order_no']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Member import Member


class MybankCreditSupplychainCreditpayBillQueryModel(object):

    def __init__(self):
        self._bill_no = None
        self._buyer = None
        self._channel_tag = None
        self._trace_id = None

    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def buyer(self):
        return self._buyer

    @buyer.setter
    def buyer(self, value):
        if isinstance(value, Member):
            self._buyer = value
        else:
            self._buyer = Member.from_alipay_dict(value)
    @property
    def channel_tag(self):
        return self._channel_tag

    @channel_tag.setter
    def channel_tag(self, value):
        self._channel_tag = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.buyer:
            if hasattr(self.buyer, 'to_alipay_dict'):
                params['buyer'] = self.buyer.to_alipay_dict()
            else:
                params['buyer'] = self.buyer
        if self.channel_tag:
            if hasattr(self.channel_tag, 'to_alipay_dict'):
                params['channel_tag'] = self.channel_tag.to_alipay_dict()
            else:
                params['channel_tag'] = self.channel_tag
        if self.trace_id:
            if hasattr(self.trace_id, 'to_alipay_dict'):
                params['trace_id'] = self.trace_id.to_alipay_dict()
            else:
                params['trace_id'] = self.trace_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditSupplychainCreditpayBillQueryModel()
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'buyer' in d:
            o.buyer = d['buyer']
        if 'channel_tag' in d:
            o.channel_tag = d['channel_tag']
        if 'trace_id' in d:
            o.trace_id = d['trace_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IntentQueryRequest(object):

    def __init__(self):
        self._action_src = None
        self._client_os = None
        self._client_version = None
        self._current_city = None
        self._location = None
        self._nlu_json_param = None
        self._open_id = None
        self._query = None
        self._query_id = None
        self._scene_code = None
        self._search_src = None
        self._session_id = None
        self._uid = None

    @property
    def action_src(self):
        return self._action_src

    @action_src.setter
    def action_src(self, value):
        self._action_src = value
    @property
    def client_os(self):
        return self._client_os

    @client_os.setter
    def client_os(self, value):
        self._client_os = value
    @property
    def client_version(self):
        return self._client_version

    @client_version.setter
    def client_version(self, value):
        self._client_version = value
    @property
    def current_city(self):
        return self._current_city

    @current_city.setter
    def current_city(self, value):
        self._current_city = value
    @property
    def location(self):
        return self._location

    @location.setter
    def location(self, value):
        self._location = value
    @property
    def nlu_json_param(self):
        return self._nlu_json_param

    @nlu_json_param.setter
    def nlu_json_param(self, value):
        self._nlu_json_param = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def query(self):
        return self._query

    @query.setter
    def query(self, value):
        self._query = value
    @property
    def query_id(self):
        return self._query_id

    @query_id.setter
    def query_id(self, value):
        self._query_id = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def search_src(self):
        return self._search_src

    @search_src.setter
    def search_src(self, value):
        self._search_src = value
    @property
    def session_id(self):
        return self._session_id

    @session_id.setter
    def session_id(self, value):
        self._session_id = value
    @property
    def uid(self):
        return self._uid

    @uid.setter
    def uid(self, value):
        self._uid = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_src:
            if hasattr(self.action_src, 'to_alipay_dict'):
                params['action_src'] = self.action_src.to_alipay_dict()
            else:
                params['action_src'] = self.action_src
        if self.client_os:
            if hasattr(self.client_os, 'to_alipay_dict'):
                params['client_os'] = self.client_os.to_alipay_dict()
            else:
                params['client_os'] = self.client_os
        if self.client_version:
            if hasattr(self.client_version, 'to_alipay_dict'):
                params['client_version'] = self.client_version.to_alipay_dict()
            else:
                params['client_version'] = self.client_version
        if self.current_city:
            if hasattr(self.current_city, 'to_alipay_dict'):
                params['current_city'] = self.current_city.to_alipay_dict()
            else:
                params['current_city'] = self.current_city
        if self.location:
            if hasattr(self.location, 'to_alipay_dict'):
                params['location'] = self.location.to_alipay_dict()
            else:
                params['location'] = self.location
        if self.nlu_json_param:
            if hasattr(self.nlu_json_param, 'to_alipay_dict'):
                params['nlu_json_param'] = self.nlu_json_param.to_alipay_dict()
            else:
                params['nlu_json_param'] = self.nlu_json_param
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.query:
            if hasattr(self.query, 'to_alipay_dict'):
                params['query'] = self.query.to_alipay_dict()
            else:
                params['query'] = self.query
        if self.query_id:
            if hasattr(self.query_id, 'to_alipay_dict'):
                params['query_id'] = self.query_id.to_alipay_dict()
            else:
                params['query_id'] = self.query_id
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.search_src:
            if hasattr(self.search_src, 'to_alipay_dict'):
                params['search_src'] = self.search_src.to_alipay_dict()
            else:
                params['search_src'] = self.search_src
        if self.session_id:
            if hasattr(self.session_id, 'to_alipay_dict'):
                params['session_id'] = self.session_id.to_alipay_dict()
            else:
                params['session_id'] = self.session_id
        if self.uid:
            if hasattr(self.uid, 'to_alipay_dict'):
                params['uid'] = self.uid.to_alipay_dict()
            else:
                params['uid'] = self.uid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IntentQueryRequest()
        if 'action_src' in d:
            o.action_src = d['action_src']
        if 'client_os' in d:
            o.client_os = d['client_os']
        if 'client_version' in d:
            o.client_version = d['client_version']
        if 'current_city' in d:
            o.current_city = d['current_city']
        if 'location' in d:
            o.location = d['location']
        if 'nlu_json_param' in d:
            o.nlu_json_param = d['nlu_json_param']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'query' in d:
            o.query = d['query']
        if 'query_id' in d:
            o.query_id = d['query_id']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'search_src' in d:
            o.search_src = d['search_src']
        if 'session_id' in d:
            o.session_id = d['session_id']
        if 'uid' in d:
            o.uid = d['uid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMarketingCampaignMerchantActivityOfflineModel(object):

    def __init__(self):
        self._activity_id = None
        self._memo = None
        self._operator = None
        self._operator_type = None
        self._out_request_no = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def operator_type(self):
        return self._operator_type

    @operator_type.setter
    def operator_type(self, value):
        self._operator_type = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.operator_type:
            if hasattr(self.operator_type, 'to_alipay_dict'):
                params['operator_type'] = self.operator_type.to_alipay_dict()
            else:
                params['operator_type'] = self.operator_type
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingCampaignMerchantActivityOfflineModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'memo' in d:
            o.memo = d['memo']
        if 'operator' in d:
            o.operator = d['operator']
        if 'operator_type' in d:
            o.operator_type = d['operator_type']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BkAgentRespInfo(object):

    def __init__(self):
        self._bindclrissr_id = None
        self._bindpyeracctbk_id = None
        self._bindtrx_id = None
        self._bkpyeruser_code = None
        self._estter_location = None

    @property
    def bindclrissr_id(self):
        return self._bindclrissr_id

    @bindclrissr_id.setter
    def bindclrissr_id(self, value):
        self._bindclrissr_id = value
    @property
    def bindpyeracctbk_id(self):
        return self._bindpyeracctbk_id

    @bindpyeracctbk_id.setter
    def bindpyeracctbk_id(self, value):
        self._bindpyeracctbk_id = value
    @property
    def bindtrx_id(self):
        return self._bindtrx_id

    @bindtrx_id.setter
    def bindtrx_id(self, value):
        self._bindtrx_id = value
    @property
    def bkpyeruser_code(self):
        return self._bkpyeruser_code

    @bkpyeruser_code.setter
    def bkpyeruser_code(self, value):
        self._bkpyeruser_code = value
    @property
    def estter_location(self):
        return self._estter_location

    @estter_location.setter
    def estter_location(self, value):
        self._estter_location = value


    def to_alipay_dict(self):
        params = dict()
        if self.bindclrissr_id:
            if hasattr(self.bindclrissr_id, 'to_alipay_dict'):
                params['bindclrissr_id'] = self.bindclrissr_id.to_alipay_dict()
            else:
                params['bindclrissr_id'] = self.bindclrissr_id
        if self.bindpyeracctbk_id:
            if hasattr(self.bindpyeracctbk_id, 'to_alipay_dict'):
                params['bindpyeracctbk_id'] = self.bindpyeracctbk_id.to_alipay_dict()
            else:
                params['bindpyeracctbk_id'] = self.bindpyeracctbk_id
        if self.bindtrx_id:
            if hasattr(self.bindtrx_id, 'to_alipay_dict'):
                params['bindtrx_id'] = self.bindtrx_id.to_alipay_dict()
            else:
                params['bindtrx_id'] = self.bindtrx_id
        if self.bkpyeruser_code:
            if hasattr(self.bkpyeruser_code, 'to_alipay_dict'):
                params['bkpyeruser_code'] = self.bkpyeruser_code.to_alipay_dict()
            else:
                params['bkpyeruser_code'] = self.bkpyeruser_code
        if self.estter_location:
            if hasattr(self.estter_location, 'to_alipay_dict'):
                params['estter_location'] = self.estter_location.to_alipay_dict()
            else:
                params['estter_location'] = self.estter_location
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BkAgentRespInfo()
        if 'bindclrissr_id' in d:
            o.bindclrissr_id = d['bindclrissr_id']
        if 'bindpyeracctbk_id' in d:
            o.bindpyeracctbk_id = d['bindpyeracctbk_id']
        if 'bindtrx_id' in d:
            o.bindtrx_id = d['bindtrx_id']
        if 'bkpyeruser_code' in d:
            o.bkpyeruser_code = d['bkpyeruser_code']
        if 'estter_location' in d:
            o.estter_location = d['estter_location']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.StuffStockInOrder import StuffStockInOrder


class KoubeiSalesKbassetStuffQuerystockinorderQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiSalesKbassetStuffQuerystockinorderQueryResponse, self).__init__()
        self._error_code = None
        self._error_desc = None
        self._ext_info = None
        self._page_no = None
        self._page_size = None
        self._stock_in_orders = None
        self._success = None
        self._total_count = None

    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_desc(self):
        return self._error_desc

    @error_desc.setter
    def error_desc(self, value):
        self._error_desc = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def stock_in_orders(self):
        return self._stock_in_orders

    @stock_in_orders.setter
    def stock_in_orders(self, value):
        if isinstance(value, list):
            self._stock_in_orders = list()
            for i in value:
                if isinstance(i, StuffStockInOrder):
                    self._stock_in_orders.append(i)
                else:
                    self._stock_in_orders.append(StuffStockInOrder.from_alipay_dict(i))
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value
    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value

    def parse_response_content(self, response_content):
        response = super(KoubeiSalesKbassetStuffQuerystockinorderQueryResponse, self).parse_response_content(response_content)
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'error_desc' in response:
            self.error_desc = response['error_desc']
        if 'ext_info' in response:
            self.ext_info = response['ext_info']
        if 'page_no' in response:
            self.page_no = response['page_no']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'stock_in_orders' in response:
            self.stock_in_orders = response['stock_in_orders']
        if 'success' in response:
            self.success = response['success']
        if 'total_count' in response:
            self.total_count = response['total_count']
